==> react-molecule-rating-1.11.0.tgz: package/lib/components/StarHover.js <==
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { useState } from 'react';
import PropTypes from 'prop-types';
import { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { IconStarOutline } from '../Icons';
import cx from 'classnames';
var BASE_CLASS = "sui-MoleculeRating-Star";
var DEFAULTS = {
  ratingValues: [1, 2, 3, 4, 5],
  IconStarEmpty: IconStarOutline
};

var MoleculeRatingStarHover = function MoleculeRatingStarHover(_ref) {
  var _ref$IconStar = _ref.IconStar,
      IconStar = _ref$IconStar === void 0 ? DEFAULTS.IconStarEmpty : _ref$IconStar,
      _ref$initialRating = _ref.initialRating,
      initialRating = _ref$initialRating === void 0 ? 0 : _ref$initialRating,
      onClick = _ref.onClick,
      size = _ref.size,
      _ref$ratingValues = _ref.ratingValues,
      ratingValues = _ref$ratingValues === void 0 ? DEFAULTS.ratingValues : _ref$ratingValues;

  var _useState = useState(null),
      selectedRating = _useState[0],
      setSelectedRating = _useState[1];

  var _useState2 = useState(initialRating),
      rating = _useState2[0],
      setRating = _useState2[1];

  var StarHover = IconStar;

  var handleClick = function handleClick(e, _ref2) {
    var value = _ref2.value;
    setRating(value);
    onClick(e, {
      value: value
    });
  };

  var renderStars = function renderStars() {
    return ratingValues.map(function (value) {
      var _cx;

      var isActive = rating >= value || value <= selectedRating;
      var className = cx(BASE_CLASS, (_cx = {}, _cx["is-active"] = isActive, _cx));
      return /*#__PURE__*/_jsx("div", {
        className: className,
        onClick: function onClick(e) {
          return handleClick(e, {
            value: value
          });
        },
        onMouseOver: function onMouseOver() {
          return setSelectedRating(value);
        },
        onMouseOut: function onMouseOut() {
          return setSelectedRating(null);
        },
        children: /*#__PURE__*/_jsx(StarHover, {
          size: size
        })
      }, value);
    });
  };

  return /*#__PURE__*/_jsx(_Fragment, {
    children: renderStars()
  });
};

MoleculeRatingStarHover.displayName = 'MoleculeRatingStarHover';
export default MoleculeRatingStarHover;

==> react-molecule-rating-1.14.0.tgz: package/lib/components/StarHover.js <==
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import { useState } from 'react';
import PropTypes from 'prop-types';
import { ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import { IconStarOutline } from '../Icons';
import cx from 'classnames';
var BASE_CLASS = "sui-MoleculeRating-Star";
var DEFAULTS = {
  ratingValues: [1, 2, 3, 4, 5],
  IconStarEmpty: IconStarOutline
};

var MoleculeRatingStarHover = function MoleculeRatingStarHover(_ref) {
  var _ref$iconStar = _ref.iconStar,
      iconStar = _ref$iconStar === void 0 ? DEFAULTS.IconStarEmpty : _ref$iconStar,
      _ref$initialRating = _ref.initialRating,
      initialRating = _ref$initialRating === void 0 ? 0 : _ref$initialRating,
      onClick = _ref.onClick,
      size = _ref.size,
      _ref$ratingValues = _ref.ratingValues,
      ratingValues = _ref$ratingValues === void 0 ? DEFAULTS.ratingValues : _ref$ratingValues;

  var _useState = useState(null),
      selectedRating = _useState[0],
      setSelectedRating = _useState[1];

  var _useState2 = useState(initialRating),
      rating = _useState2[0],
      setRating = _useState2[1];

  var StarHover = iconStar;

  var handleClick = function handleClick(e, _ref2) {
    var value = _ref2.value;
    setRating(value);
    onClick(e, {
      value: value
    });
  };

  var renderStars = function renderStars() {
    return ratingValues.map(function (value) {
      var _cx;

      var isActive = rating >= value || value <= selectedRating;
      var className = cx(BASE_CLASS, (_cx = {}, _cx["is-active"] = isActive, _cx));
      return /*#__PURE__*/_jsx("div", {
        className: className,
        onClick: function onClick(e) {
          return handleClick(e, {
            value: value
          });
        },
        onMouseOver: function onMouseOver() {
          return setSelectedRating(value);
        },
        onMouseOut: function onMouseOut() {
          return setSelectedRating(null);
        },
        children: /*#__PURE__*/_jsx(StarHover, {
          size: size
        })
      }, value);
    });
  };

  return /*#__PURE__*/_jsx(_Fragment, {
    children: renderStars()
  });
};

MoleculeRatingStarHover.displayName = 'MoleculeRatingStarHover';
export default MoleculeRatingStarHover;
